@@ -19,11 +19,15 @@ run_interactiveforestplot <- function(data = NULL) {
   }
 
   if (!is.null(data)) {
+    coveffectsplot_initdata <- NULL # fix no visible binding for coveffectsplot_initdata
     .GlobalEnv$coveffectsplot_initdata <- data
     on.exit(rm(coveffectsplot_initdata, envir = .GlobalEnv))
   }
   shiny::runApp(appDir, display.mode = "normal")
 }
 
-# Make CRAN happy
-if (getRversion() >= "2.15.1") utils::globalVariables(c("coveffectsplot_initdata"))
\ No newline at end of file
+.onAttach <- function(libname, pkgname) {
+  packageStartupMessage("Thank you for using coveffectsplot!\nif you find it useful, please cite as:")
+  packageStartupMessage("JF Marier, N Teuscher and MS Mouksassi. Evaluation of covariate effects using forest plots and introduction to the coveffectsplot R package. CPT Pharmacometrics Syst Pharmacol. 2022;11:1283-1293. doi:10.1002/psp4.12829")
+}
+
